# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/onu_inter_adapter_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import inter_adapter_pb2 as voltha__protos_dot_inter__adapter__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/onu_inter_adapter_service.proto',
  package='onu_inter_adapter_service',
  syntax='proto3',
  serialized_options=b'\n-org.opencord.voltha.onu_inter_adapter_serviceB\034VolthaOnuInterAdapterServiceZAgithub.com/opencord/voltha-protos/v5/go/onu_inter_adapter_service',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-voltha_protos/onu_inter_adapter_service.proto\x12\x19onu_inter_adapter_service\x1a\x1avoltha_protos/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a!voltha_protos/inter_adapter.proto\x1a\x1avoltha_protos/health.proto2\xdf\x03\n\x16OnuInterAdapterService\x12?\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus(\x01\x30\x01\x12L\n\rOnuIndication\x12#.inter_adapter.OnuIndicationMessage\x1a\x16.google.protobuf.Empty\x12\x44\n\x0eOmciIndication\x12\x1a.inter_adapter.OmciMessage\x1a\x16.google.protobuf.Empty\x12X\n\x13\x44ownloadTechProfile\x12).inter_adapter.TechProfileDownloadMessage\x1a\x16.google.protobuf.Empty\x12L\n\rDeleteGemPort\x12#.inter_adapter.DeleteGemPortMessage\x1a\x16.google.protobuf.Empty\x12H\n\x0b\x44\x65leteTCont\x12!.inter_adapter.DeleteTcontMessage\x1a\x16.google.protobuf.EmptyB\x90\x01\n-org.opencord.voltha.onu_inter_adapter_serviceB\x1cVolthaOnuInterAdapterServiceZAgithub.com/opencord/voltha-protos/v5/go/onu_inter_adapter_serviceb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_inter__adapter__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_ONUINTERADAPTERSERVICE = _descriptor.ServiceDescriptor(
  name='OnuInterAdapterService',
  full_name='onu_inter_adapter_service.OnuInterAdapterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=197,
  serialized_end=676,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='onu_inter_adapter_service.OnuInterAdapterService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._CONNECTION,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnuIndication',
    full_name='onu_inter_adapter_service.OnuInterAdapterService.OnuIndication',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_inter__adapter__pb2._ONUINDICATIONMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OmciIndication',
    full_name='onu_inter_adapter_service.OnuInterAdapterService.OmciIndication',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_inter__adapter__pb2._OMCIMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadTechProfile',
    full_name='onu_inter_adapter_service.OnuInterAdapterService.DownloadTechProfile',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_inter__adapter__pb2._TECHPROFILEDOWNLOADMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteGemPort',
    full_name='onu_inter_adapter_service.OnuInterAdapterService.DeleteGemPort',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_inter__adapter__pb2._DELETEGEMPORTMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTCont',
    full_name='onu_inter_adapter_service.OnuInterAdapterService.DeleteTCont',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_inter__adapter__pb2._DELETETCONTMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ONUINTERADAPTERSERVICE)

DESCRIPTOR.services_by_name['OnuInterAdapterService'] = _ONUINTERADAPTERSERVICE

# @@protoc_insertion_point(module_scope)
